# ServiceNow Integration FAQs
### On this page
  * [Integration Setup](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs#integration-setup)
  * [Data Linking and Mapping](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs#data-linking-and-mapping)
  * [Data Synchronization](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs#data-synchronization)
  * [Data Linking and Relation Management](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs#data-linking-and-relation-management)
  * [Fact Sheet Management](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs#fact-sheet-management)
  * [Lifecycle Management](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs#lifecycle-management)
  * [Tech Category Management](https://help.sap.com/docs/leanix/ea/servicenow-integration-faqs#tech-category-management)


Find answers to frequently asked questions about the ServiceNow integration.
